@@ -87,6 +87,7 @@ def _build_ca_extentions():
     key_usage = x509.KeyUsage(False, False, False, False, False, True, False,
                               False, False)
     key_usage = x509.Extension(key_usage.oid, True, key_usage)
+
     basic_constraints = x509.BasicConstraints(ca=True, path_length=0)
     basic_constraints = x509.Extension(basic_constraints.oid, True,
                                        basic_constraints)
@@ -133,6 +134,9 @@ def _generate_certificate(issuer_name, subject_name, extensions,
 
     csr = csr.sign(private_key, hashes.SHA256(), default_backend())
 
+    if six.PY3 and isinstance(encryption_password, six.text_type):
+        encryption_password = encryption_password.encode()
+
     if encryption_password:
         encryption_algorithm = serialization.BestAvailableEncryption(
             encryption_password)
@@ -196,7 +200,7 @@ def sign(csr, issuer_name, ca_key, ca_key_password=None,
         try:
             csr = x509.load_pem_x509_csr(csr, backend=default_backend())
         except ValueError:
-            LOG.exception("Received invalid csr {0}.".format(csr))
+            LOG.exception("Received invalid csr %s.", csr)
             raise exception.InvalidCsr(csr=csr)
 
     term_of_validity = CONF.x509.term_of_validity
@@ -231,6 +235,35 @@ def sign(csr, issuer_name, ca_key, ca_key_password=None,
     return certificate
 
 
+def generate_csr_and_key(common_name):
+    """Return a dict with a new csr, public key and private key."""
+    private_key = rsa.generate_private_key(
+        public_exponent=65537,
+        key_size=2048,
+        backend=default_backend())
+
+    public_key = private_key.public_key()
+
+    csr = x509.CertificateSigningRequestBuilder().subject_name(x509.Name([
+        x509.NameAttribute(x509.oid.NameOID.COMMON_NAME, common_name),
+    ])).sign(private_key, hashes.SHA256(), default_backend())
+
+    result = {
+        'csr': csr.public_bytes(
+            encoding=serialization.Encoding.PEM).decode("utf-8"),
+        'private_key': private_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.TraditionalOpenSSL,
+            encryption_algorithm=serialization.NoEncryption()).decode("utf-8"),
+        'public_key': public_key.public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.SubjectPublicKeyInfo).decode(
+                "utf-8"),
+    }
+
+    return result
+
+
 def decrypt_key(encrypted_key, password):
     private_key = _load_pem_private_key(encrypted_key, password)
 
