@@ -1,5 +1,3 @@
-#!/bin/sh
-
 echo "START: write-heat-params"
 
 arch=$(uname -m)
@@ -70,6 +68,7 @@ REGION_NAME="$REGION_NAME"
 HTTP_PROXY="$HTTP_PROXY"
 HTTPS_PROXY="$HTTPS_PROXY"
 NO_PROXY="$NO_PROXY"
+HYPERKUBE_PREFIX="$HYPERKUBE_PREFIX"
 KUBE_TAG="$KUBE_TAG"
 CLOUD_PROVIDER_TAG="$CLOUD_PROVIDER_TAG"
 CLOUD_PROVIDER_ENABLED="$CLOUD_PROVIDER_ENABLED"
@@ -117,6 +116,8 @@ EXTERNAL_NETWORK_ID="$EXTERNAL_NETWORK_ID"
 TILLER_ENABLED="$TILLER_ENABLED"
 TILLER_TAG="$TILLER_TAG"
 TILLER_NAMESPACE="$TILLER_NAMESPACE"
+HELM_CLIENT_URL="$HELM_CLIENT_URL"
+HELM_CLIENT_SHA256="$HELM_CLIENT_SHA256"
 HELM_CLIENT_TAG="$HELM_CLIENT_TAG"
 NODE_PROBLEM_DETECTOR_TAG="$NODE_PROBLEM_DETECTOR_TAG"
 NGINX_INGRESS_CONTROLLER_TAG="$NGINX_INGRESS_CONTROLLER_TAG"
